@@ -1,5 +1,5 @@
 import { camelCase, lowerCase, lowerFirst, startCase, upperFirst } from 'lodash';
-import { AggregateError, Op } from 'sequelize';
+import { Op } from 'sequelize';
 import { ValidationError as YupValidationError } from 'yup';
 import config from 'config';
 
@@ -7,7 +7,7 @@ import { ForeignkeyResolutionError, UpsertionError, ValidationError } from '../e
 import { statkey, updateStat } from '../stats';
 import * as schemas from '../importSchemas';
 import { validateTableRows } from './validateTableRows';
-import { generateTranslationsForData } from './translationHandler';
+import { generateTranslationsForData, bulkUpsertTranslationDefaults } from './translationHandler';
 
 function findFieldName(values, fkField) {
   const fkFieldLower = fkField.toLowerCase();
@@ -241,6 +241,7 @@ export async function importRows(
   await validateTableRows(models, validRows, pushErrorFn);
 
   log.debug('Upserting database rows', { rows: validRows.length });
+  const translationData = [];
   for (const { model, sheetRow, values } of validRows) {
     const Model = models[model];
     const existing = await loadExisting(Model, values);
@@ -267,9 +268,10 @@ export async function importRows(
               'SurveyScreenComponent',
               'UserFacility',
               'ProcedureTypeSurvey',
+              'TranslatedString',
             ].includes(model)
           ) {
-            throw new ValidationError(`Deleting ${model} via the importer is not supported`);
+            throw new Error(`Deleting ${model} via the importer is not supported`);
           }
           if (!existing.deletedAt) {
             updateStat(stats, statkey(model, sheetName), 'updated');
@@ -304,29 +306,18 @@ export async function importRows(
         await Model.create(normalizedValues);
         updateStat(stats, statkey(model, sheetName), 'created');
       }
-
       const recordTranslationData = generateTranslationsForData(model, sheetName, normalizedValues);
-      try {
-        await models.TranslatedString.bulkCreate(recordTranslationData, {
-          validate: true,
-          updateOnDuplicate: ['text'],
-        });
-      } catch (err) {
-        if (!(err instanceof AggregateError)) {
-          throw err; // Not a sequelize bulk create error, so let it bubble up
-        }
-
-        updateStat(stats, statkey(model, sheetName), 'errored');
-        for (const error of err.errors) {
-          errors.push(new ValidationError(sheetName, sheetRow, error.message));
-        }
-      }
+      translationData.push(...recordTranslationData);
     } catch (err) {
       updateStat(stats, statkey(model, sheetName), 'errored');
       errors.push(new UpsertionError(sheetName, sheetRow, err));
     }
   }
 
+  if (errors.length === 0) {
+    await bulkUpsertTranslationDefaults(models, translationData);
+  }
+
   log.debug('Done with these rows');
   return stats;
 }
