@@ -196,18 +196,13 @@ export function fakeEncounterDiagnosis(prefix: string = 'test-') {
   };
 }
 
-export function fakeEncounterMedication(prefix: string = 'test-') {
+export function fakePrescription(prefix: string = 'test-') {
   const id = fakeUUID();
   return {
     date: formatISO9075(chance.date()),
     endDate: formatISO9075(chance.date()),
-    qtyMorning: chance.integer({ min: 0, max: 10 }),
-    qtyLunch: chance.integer({ min: 0, max: 10 }),
-    qtyEvening: chance.integer({ min: 0, max: 10 }),
-    qtyNight: chance.integer({ min: 0, max: 10 }),
-    ...fakeStringFields(`${prefix}encounterMedication_${id}_`, [
+    ...fakeStringFields(`${prefix}prescription${id}_`, [
       'id',
-      'prescription',
       'note',
       'indication',
       'route',
@@ -362,7 +357,8 @@ const MODEL_SPECIFIC_OVERRIDES = {
       stillborn: chance.pickone(options),
     };
   },
-  PatientProgramRegistration: () => ({
+  PatientProgramRegistration: ({ patientId, programRegistryId }) => ({
+    id: `${patientId.replaceAll(';', ':')};${programRegistryId.replaceAll(';', ':')}`,
     registrationStatus: REGISTRATION_STATUSES.ACTIVE,
   }),
   User: () => ({
