@@ -4,8 +4,8 @@ import { useLanguageContext } from './languageContext';
 import { flatten } from './flattenStyles';
 
 export const Page = ({ style, ...props }) => {
-  const { makeIntlStyleSheet } = useLanguageContext();
+  const { makeIntlStyleSheet, pdfFont } = useLanguageContext();
   const mergedStyle = flatten(style);
-  const newStyles = makeIntlStyleSheet({ fontFamily: 'Helvetica', ...mergedStyle });
+  const newStyles = makeIntlStyleSheet({ fontFamily: pdfFont, ...mergedStyle });
   return <BasePage style={newStyles} {...props} />;
 };
